#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_GENEIG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_GENEIG_HPP_INCLUDED

#include <nt2/linalg/include/functions/scalar/geneig.hpp>

#endif
